@@ -63,19 +63,20 @@ use_course <- function(url, destdir = getOption("usethis.destdir")) {
   check_path_is_directory(destdir)
 
   if (destdir_not_specified && is_interactive()) {
-    ui_line(c(
-      "Downloading into {ui_path(destdir)}.",
-      "Prefer a different location? Cancel, try again, and specify {ui_code('destdir')}"
+    ui_bullets(c(
+      "i" = "Downloading into {.path {pth(destdir)}}.",
+      "_" = "Prefer a different location? Cancel, try again, and specify
+             {.arg destdir}."
     ))
-    if (ui_nope("OK to proceed?")) {
-      ui_oops("Cancelling download.")
+    if (ui_nah("OK to proceed?")) {
+      ui_bullets(c(x = "Cancelling download."))
       return(invisible())
     }
   }
 
-  ui_done("Downloading from {ui_value(url)}")
+  ui_bullets(c("v" = "Downloading from {.url {url}}."))
   zipfile <- tidy_download(url, destdir)
-  ui_done("Download stored in {ui_path(zipfile)}")
+  ui_bullets(c("v" = "Download stored in {.path {pth(zipfile)}}."))
   check_is_zip(attr(zipfile, "content-type"))
   tidy_unzip(zipfile, cleanup = NA)
 }
@@ -90,9 +91,9 @@ use_zip <- function(url,
                     cleanup = if (rlang::is_interactive()) NA else FALSE) {
   url <- normalize_url(url)
   check_path_is_directory(destdir)
-  ui_done("Downloading from {ui_value(url)}")
+  ui_bullets(c("v" = "Downloading from {.url {url}}."))
   zipfile <- tidy_download(url, destdir)
-  ui_done("Download stored in {ui_path(zipfile)}")
+  ui_bullets(c("v" = "Download stored in {.path {pth(zipfile)}}."))
   check_is_zip(attr(zipfile, "content-type"))
   tidy_unzip(zipfile, cleanup)
 }
@@ -255,14 +256,15 @@ tidy_download <- function(url, destdir = getwd()) {
   tmp <- file_temp("tidy-download-")
 
   h <- download_url(url, destfile = tmp)
-  ui_line()
+  cli::cat_line()
 
   cd <- content_disposition(h)
   base_name <- make_filename(cd, fallback = path_file(url))
   full_path <- path(destdir, base_name)
 
   if (!can_overwrite(full_path)) {
-    ui_stop("Cancelling download, to avoid overwriting {ui_path(full_path)}")
+    ui_abort("
+      Cancelling download, to avoid overwriting {.path {pth(full_path)}}.")
   }
   attr(full_path, "content-type") <- content_type(h)
   attr(full_path, "content-disposition") <- cd
@@ -303,12 +305,12 @@ download_url <- function(url,
 
   status <- try_download(url, destfile, handle = handle)
   if (inherits(status, "error") && is_interactive()) {
-    ui_oops(status$message)
-    if (ui_nope("
-      Download failed :(
-      See above for everything we know about why it failed.
-      Shall we try a couple more times, with a longer timeout?
-    ")) {
+    ui_bullets(c("x" = status$message))
+    if (ui_nah(c(
+      "!" = "Download failed :(",
+      "i" = "See above for everything we know about why it failed.",
+      " " = "Shall we try a couple more times, with a longer timeout?"
+    ))) {
       n_tries <- 1
     }
   }
@@ -323,7 +325,7 @@ download_url <- function(url,
       )
     }
     i <- i + 1
-    ui_info("Retrying download ... attempt {i}")
+    ui_bullets(c("i" = "Retrying download ... attempt {i}."))
     status <- try_download(url, destfile, handle = handle)
   }
 
@@ -358,43 +360,45 @@ tidy_unzip <- function(zipfile, cleanup = FALSE) {
   ## DropBox ZIP files often include lots of hidden R, RStudio, and Git files
   filenames <- filenames[keep_lgl(filenames)]
 
-  td <- top_directory(filenames)
-  loose_parts <- is.na(td)
-
-  if (loose_parts) {
+  parents <- path_before_slash(filenames)
+  unique_parents <- unique(parents)
+  if (length(unique_parents) == 1 && unique_parents != "") {
+    target <- path(base_path, unique_parents)
+    utils::unzip(zipfile, files = filenames, exdir = base_path)
+  } else {
+    # there is no parent; archive contains loose parts
     target <- path_ext_remove(zipfile)
     utils::unzip(zipfile, files = filenames, exdir = target)
-  } else {
-    target <- path(base_path, td)
-    utils::unzip(zipfile, files = filenames, exdir = base_path)
   }
-  ui_done(
-    "Unpacking ZIP file into {ui_path(target, base_path)} \\
-    ({length(filenames)} files extracted)"
-  )
+  ui_bullets(c(
+    "v" = "Unpacking ZIP file into {.path {pth(target, base_path)}}
+           ({length(filenames)} file{?s} extracted)."
+  ))
 
   if (isNA(cleanup)) {
     cleanup <- is_interactive() &&
-      ui_yeah("Shall we delete the ZIP file ({ui_path(zipfile, base_path)})?")
+      ui_yep("Shall we delete the ZIP file ({.path {pth(zipfile, base_path)}})?")
   }
 
   if (isTRUE(cleanup)) {
-    ui_done("Deleting {ui_path(zipfile, base_path)}")
+    ui_bullets(c("v" = "Deleting {.path {pth(zipfile, base_path)}}."))
     file_delete(zipfile)
   }
 
   if (is_interactive()) {
     rproj_path <- rproj_paths(target)
     if (length(rproj_path) == 1 && rstudioapi::hasFun("openProject")) {
-      ui_done("Opening project in RStudio")
+      ui_bullets(c("v" = "Opening project in RStudio."))
       rstudioapi::openProject(target, newSession = TRUE)
     } else if (!in_rstudio_server()) {
-      ui_done("Opening {ui_path(target, base_path)} in the file manager")
+      ui_bullets(c(
+        "v" = "Opening {.path {pth(target, base_path)}} in the file manager."
+      ))
       utils::browseURL(path_real(target))
     }
   }
 
-  invisible(target)
+  invisible(unclass(target))
 }
 
 #' @rdname use_course_details
@@ -462,10 +466,10 @@ modify_github_url <- function(url) {
 }
 
 hopeless_url <- function(url) {
-  ui_info(
-    "URL does not match a recognized form for Google Drive or DropBox. \\
-     No change made."
-  )
+  ui_bullets(c(
+    "!" = "URL does not match a recognized form for Google Drive or DropBox;
+           no change made."
+  ))
   url
 }
 
@@ -521,15 +525,17 @@ keep_lgl <- function(file,
   !grepl(ignores, file, perl = TRUE)
 }
 
-top_directory <- function(filenames) {
-  in_top <- path_dir(filenames) == "."
-  unique_top <- unique(filenames[in_top])
-  is_directory <- grepl("/$", unique_top)
-  if (length(unique_top) > 1 || !is_directory) {
-    NA_character_
-  } else {
-    unique_top
+path_before_slash <- function(filepath) {
+  f <- function(x) {
+    parts <- strsplit(x, "/", fixed = TRUE)[[1]]
+    if (length(parts) > 1 || grepl("/", x)) {
+      parts[1]
+    } else {
+      ""
+    }
   }
+  purrr::map_chr(filepath, f)
+
 }
 
 content_type <- function(h) {
@@ -552,9 +558,9 @@ check_is_zip <- function(ct) {
   # see https://github.com/r-lib/usethis/issues/573
   allowed <- c("application/zip", "application/x-zip-compressed")
   if (!ct %in% allowed) {
-    ui_stop(c(
-      "Download does not have MIME type {ui_value('application/zip')}.",
-      "Instead it's {ui_value(ct)}."
+    ui_abort(c(
+      "Download does not have MIME type {.val application/zip}.",
+      "Instead it's {.val {ct}}."
     ))
   }
   invisible(ct)
@@ -568,9 +574,9 @@ check_is_zip <- function(ct) {
 # http://test.greenbytes.de/tech/tc2231/
 parse_content_disposition <- function(cd) {
   if (!grepl("^attachment;", cd)) {
-    ui_stop(c(
-      "{ui_code('Content-Disposition')} header doesn't start with {ui_value('attachment')}.",
-      "Actual header: {ui_value(cd)}"
+    ui_abort(c(
+      "{.code Content-Disposition} header doesn't start with {.val attachment}.",
+      "Actual header: {.val cd}"
     ))
   }
 
