@@ -4,7 +4,7 @@
 #' `use_github()` takes a local project and:
 #' * Checks that the initial state is good to go:
 #'   - Project is already a Git repo
-#'   - Current branch is the default branch, e.g. `master` or `main`
+#'   - Current branch is the default branch, e.g. `main` or `master`
 #'   - No uncommitted changes
 #'   - No pre-existing `origin` remote
 #' * Creates an associated repo on GitHub
@@ -12,7 +12,7 @@
 #' * Makes an initial push to GitHub
 #' * Calls [use_github_links()], if the project is an R package
 #' * Configures `origin/DEFAULT` to be the upstream branch of the local
-#'   `DEFAULT` branch, e.g. `master` or `main`
+#'   `DEFAULT` branch, e.g. `main` or `master`
 #'
 #' See below for the authentication setup that is necessary for all of this to
 #' work.
@@ -39,11 +39,6 @@
 #'   For a hypothetical GitHub Enterprise instance, either
 #'   "https://github.acme.com/api/v3" or "https://github.acme.com" is
 #'   acceptable.
-#' @param auth_token,credentials `r lifecycle::badge("deprecated")`: No longer
-#'   consulted now that usethis uses the gert package for Git operations,
-#'   instead of git2r; gert relies on the credentials package for auth. The API
-#'   requests are now authorized with the token associated with the `host`, as
-#'   retrieved by [gh::gh_token()].
 #'
 #' @export
 #' @examples
@@ -61,16 +56,7 @@ use_github <- function(organisation = NULL,
                        private = FALSE,
                        visibility = c("public", "private", "internal"),
                        protocol = git_protocol(),
-                       host = NULL,
-                       auth_token = deprecated(),
-                       credentials = deprecated()) {
-  if (lifecycle::is_present(auth_token)) {
-    deprecate_warn_auth_token("use_github")
-  }
-  if (lifecycle::is_present(credentials)) {
-    deprecate_warn_credentials("use_github")
-  }
-
+                       host = NULL) {
   visibility_specified <- !missing(visibility)
   visibility <- match.arg(visibility)
   check_protocol(protocol)
@@ -80,7 +66,7 @@ use_github <- function(organisation = NULL,
     is = default_branch,
     # glue-ing happens inside check_current_branch(), where `gb` gives the
     # current branch
-    "Must be on the default branch ({ui_value(is)}), not {ui_value(gb)}."
+    message = c("x" = "Must be on the default branch {.val {is}}, not {.val {gb}}.")
   )
   challenge_uncommitted_changes(msg = "
     There are uncommitted changes and we're about to create and push to a new \\
@@ -89,10 +75,9 @@ use_github <- function(organisation = NULL,
 
   if (is.null(organisation)) {
     if (visibility_specified) {
-      ui_stop("
-        The {ui_code('visibility')} setting is only relevant for
-        organisation-owned repos, within the context of certain \\
-        GitHub Enterprise products.")
+      ui_abort("
+        The {.arg visibility} setting is only relevant for organisation-owned
+        repos, within the context of certain GitHub Enterprise products.")
     }
     visibility <- if (private) "private" else "public"
   }
@@ -103,27 +88,29 @@ use_github <- function(organisation = NULL,
 
   whoami <- suppressMessages(gh::gh_whoami(.api_url = host))
   if (is.null(whoami)) {
-    ui_stop("
-      Unable to discover a GitHub personal access token
-      A token is required in order to create and push to a new repo
-
-      Call {ui_code('gh_token_help()')} for help configuring a token")
+    ui_abort(c(
+      "x" = "Unable to discover a GitHub personal access token.",
+      "i" = "A token is required in order to create and push to a new repo.",
+      "_" = "Call {.run usethis::gh_token_help()} for help configuring a token."
+    ))
   }
   empirical_host <- parse_github_remotes(glue("{whoami$html_url}/REPO"))$host
   if (empirical_host != "github.com") {
-    ui_info("Targeting the GitHub host {ui_value(empirical_host)}")
+    ui_bullets(c("i" = "Targeting the GitHub host {.val {empirical_host}}."))
   }
 
   owner <- organisation %||% whoami$login
   repo_name <- project_name()
   check_no_github_repo(owner, repo_name, host)
 
-  repo_desc <- if (is_package()) package_data()$Title %||% "" else ""
+  repo_desc <- if (is_package()) proj_desc()$get_field("Title") %||% "" else ""
   repo_desc <- gsub("\n", " ", repo_desc)
   repo_spec <- glue("{owner}/{repo_name}")
 
   visibility_string <- if (visibility == "public") "" else glue("{visibility} ")
-  ui_done("Creating {visibility_string}GitHub repository {ui_value(repo_spec)}")
+  ui_bullets(c(
+    "v" = "Creating {visibility_string}GitHub repository {.val {repo_spec}}."
+  ))
   if (is.null(organisation)) {
     create <- gh::gh(
       "POST /user/repos",
@@ -153,12 +140,12 @@ use_github <- function(organisation = NULL,
   )
   withr::defer(view_url(create$html_url))
 
-  ui_done("Setting remote {ui_value('origin')} to {ui_value(origin_url)}")
+  ui_bullets(c("v" = "Setting remote {.val origin} to {.val {origin_url}}."))
   use_git_remote("origin", origin_url)
 
   if (is_package()) {
     # we tryCatch(), because we can't afford any failure here to result in not
-    # making the first push and configuring default branch
+    # doing the first push and configuring the default branch
     # such an incomplete setup is hard to diagnose / repair post hoc
     tryCatch(
       use_github_links(),
@@ -166,22 +153,12 @@ use_github <- function(organisation = NULL,
     )
   }
 
-  repo <- git_repo()
-  remref <- glue("origin/{default_branch}")
-  ui_done("
-    Pushing {ui_value(default_branch)} branch to GitHub and setting \\
-    {ui_value(remref)} as upstream branch")
-  gert::git_push(
-    remote = "origin",
-    set_upstream = TRUE,
-    repo = repo,
-    verbose = FALSE
-  )
+  git_push_first(default_branch, "origin")
 
+  repo <- git_repo()
   gbl <- gert::git_branch_list(local = TRUE, repo = repo)
   if (nrow(gbl) > 1) {
-    ui_done("
-      Setting {ui_value(default_branch)} as default branch on GitHub")
+    ui_bullets(c("v" = "Setting {.val {default_branch}} as default branch on GitHub."))
     gh::gh(
       "PATCH /repos/{owner}/{repo}",
       owner = owner, repo = repo_name,
@@ -206,9 +183,6 @@ use_github <- function(organisation = NULL,
 #'   an interactive session, the user can confirm which repo to use for the
 #'   links. In a noninteractive session, links are formed using `upstream`.
 #'
-#' @param host,auth_token `r lifecycle::badge("deprecated")`: No longer consulted
-#'   now that usethis consults the current project's GitHub remotes to get the
-#'   `host` and then relies on gh to discover an appropriate token.
 #' @param overwrite By default, `use_github_links()` will not overwrite existing
 #'   fields. Set to `TRUE` to overwrite existing links.
 #' @export
@@ -217,26 +191,16 @@ use_github <- function(organisation = NULL,
 #' use_github_links()
 #' }
 #'
-use_github_links <- function(auth_token = deprecated(),
-                             host = deprecated(),
-                             overwrite = FALSE) {
-  if (lifecycle::is_present(auth_token)) {
-    deprecate_warn_auth_token("use_github_links")
-  }
-  if (lifecycle::is_present(host)) {
-    deprecate_warn_host("use_github_links")
-  }
-
+use_github_links <- function(overwrite = FALSE) {
   check_is_package("use_github_links()")
-  tr <- target_repo(github_get = TRUE)
 
-  gh <- gh_tr(tr)
-  res <- gh("GET /repos/{owner}/{repo}")
+  gh_url <- github_url_from_git_remotes()
 
-  use_description_field("URL", res$html_url, overwrite = overwrite)
-  use_description_field(
+  proj_desc_field_update("URL", gh_url, overwrite = overwrite, append = TRUE)
+
+  proj_desc_field_update(
     "BugReports",
-    glue("{res$html_url}/issues"),
+    glue("{gh_url}/issues"),
     overwrite = overwrite
   )
 
@@ -249,34 +213,54 @@ use_github_links <- function(auth_token = deprecated(),
   invisible()
 }
 
+has_github_links <- function(target_repo = NULL) {
+  url <- if (is.null(target_repo)) NULL else target_repo$url
+  github_url <- github_url_from_git_remotes(url)
+  if (is.null(github_url)) {
+    return(FALSE)
+  }
+
+  desc <- proj_desc()
+
+  has_github_url <- github_url %in% desc$get_urls()
+
+  bug_reports <- desc$get_field("BugReports", default = character())
+  has_github_issues <- glue("{github_url}/issues") %in% bug_reports
+
+  has_github_url && has_github_issues
+}
+
 check_no_origin <- function() {
   remotes <- git_remotes()
   if ("origin" %in% names(remotes)) {
-    ui_stop("
-      This repo already has an {ui_value('origin')} remote, \\
-      with value {ui_value(remotes[['origin']])}.
-      You can remove this setting with:
-      {ui_code('usethis::use_git_remote(\"origin\", url = NULL, overwrite = TRUE)')}")
+    ui_abort(c(
+      "x" = "This repo already has an {.val origin} remote, with value
+             {.val {remotes[['origin']]}}.",
+      "i" = "You can remove this setting with:",
+      " " = '{.code usethis::use_git_remote("origin", url = NULL, overwrite = TRUE)}'
+    ))
   }
   invisible()
 }
 
 check_no_github_repo <- function(owner, repo, host) {
+  spec <- glue("{owner}/{repo}")
   repo_found <- tryCatch(
     {
-      repo_info <- gh::gh(
-        "/repos/{owner}/{repo}",
-        owner = owner, repo = repo,
-        .api_url = host
-      )
-      TRUE
+      repo_info <- gh::gh("/repos/{spec}", spec = spec, .api_url = host)
+      # when does repo_info$full_name != the spec we sent?
+      # this happens if you reuse the original name of a repo that has since
+      # been renamed
+      # there's no 404, because of the automatic redirect, but you CAN create
+      # a new repo with this name
+      # https://github.com/r-lib/usethis/issues/1893
+      repo_info$full_name == spec
     },
     "http_error_404" = function(err) FALSE
   )
   if (!repo_found) {
     return(invisible())
   }
-  spec <- glue("{owner}/{repo}")
   empirical_host <- parse_github_remotes(repo_info$html_url)$host
-  ui_stop("Repo {ui_value(spec)} already exists on {ui_value(empirical_host)}")
+  ui_abort("Repo {.val {spec}} already exists on {.val {empirical_host}}.")
 }
