@@ -22,14 +22,21 @@
 #' article walks through the process of making a pull request with the `pr_*`
 #' functions.
 #'
+
 #' The `pr_*` functions also use your Git/GitHub credentials to carry out
-#' various remote operations. See below for more.
+#' various remote operations; see below for more about auth. The `pr_*`
+#' functions also proactively check for agreement re: the default branch in your
+#' local repo and the source repo. See [git_default_branch()] for more.
 #'
+
 #' @template double-auth
 #'
+
 #' @section For contributors:
-#' To contribute to a package, first use `create_from_github("OWNER/REPO")` to
-#' fork the source repository, and then check out a local copy.
+
+#' To contribute to a package, first use `create_from_github("OWNER/REPO")`.
+#' This forks the source repository and checks out a local copy.
+
 #'
 #' Next use `pr_init()` to create a branch for your PR. It is best practice to
 #' never make commits to the default branch branch of a fork (usually named
@@ -73,10 +80,16 @@
 #'
 #' @section Overview of all the functions:
 
-#' * `pr_init()`: Does a preparatory pull of the default branch from the source
-#' repo, to get a good start point. Creates and checks out a new branch. Nothing
-#' is pushed to or created on GitHub (that does not happen until the first time
-#' you call `pr_push()`).
+#' * `pr_init()`: As a contributor, start work on a new PR by ensuring that
+#' your local repo is up-to-date, then creating and checking out a new branch.
+#' Nothing is pushed to or created on GitHub until you call `pr_push()`.
+
+#' * `pr_fetch()`: As a maintainer, review or contribute changes to an existing
+#' PR by creating a local branch that tracks the remote PR. `pr_fetch()` does as
+#' little work as possible, so you can also use it to resume work on an PR that
+#' already has a local branch (where it will also ensure your local branch is
+#' up-to-date). If called with no arguments, up to 9 open PRs are offered for
+#' interactive selection.
 
 #' * `pr_resume()`: Resume work on a PR by switching to an existing local branch
 #' and pulling any changes from its upstream tracking branch, if it has one. If
@@ -84,15 +97,6 @@
 #' selection, with a preference for branches connected to PRs and for branches
 #' with recent activity.
 
-#' * `pr_fetch()`: Checks out a PR on the source repo for local exploration. If
-#' called with no arguments, up to 9 open PRs are offered for interactive
-#' selection. This can cause a new remote to be configured and a new local
-#' branch to be created. The local branch is configured to track its remote
-#' counterpart. The transport protocol (HTTPS vs SSH) for any new remote is
-#' inherited from the remote representing the source repo. `pr_fetch()` puts a
-#' maintainer in a position where they can push changes into an internal or
-#' external PR via `pr_push()`.
-
 #' * `pr_push()`: The first time it's called, a PR branch is pushed to GitHub
 #' and you're taken to a webpage where a new PR (or draft PR) can be created.
 #' This also sets up the local branch to track its remote counterpart.
@@ -108,8 +112,9 @@
 #' default branch or when it's a PR branch.
 
 #' * `pr_pause()`: Makes sure you're up-to-date with any remote changes in the
-#' PR. Then switches back to the default branch (usually named `main` or
-#' `master`) and pulls from the source repo.
+#' PR. Then switches back to the default branch and pulls from the source repo.
+#' Use `pr_resume()` with name of branch or use `pr_fetch()` to resume using PR
+#' number.
 
 #' * `pr_view()`: Visits the PR associated with the current branch in the
 #' browser (default) or the specific PR identified by `number`.
@@ -146,13 +151,14 @@ NULL
 #'   branch, note this should usually consist of lower case letters, numbers,
 #'   and `-`.
 pr_init <- function(branch) {
-  stopifnot(is_string(branch))
+  check_string(branch)
   repo <- git_repo()
 
   if (gert::git_branch_exists(branch, local = TRUE, repo = repo)) {
-    code <- glue("pr_resume(\"{branch}\")")
-    ui_info("
-      Branch {ui_value(branch)} already exists, calling {ui_code(code)}")
+    code <- glue('pr_resume("{branch}")')
+    ui_bullets(c(
+      "i" = "Branch {.val {branch}} already exists, calling {.code {code}}."
+    ))
     return(pr_resume(branch))
   }
 
@@ -164,19 +170,24 @@ pr_init <- function(branch) {
 
   maybe_good_configs <- c("maybe_ours_or_theirs", "maybe_fork")
   if (cfg$type %in% maybe_good_configs) {
-    ui_line('
-      Unable to confirm the GitHub remote configuration is "pull request ready"
-      You probably need to configure a personal access token for \\
-      {ui_value(tr$host)}
-      See {ui_code("gh_token_help()")} for help
-      (Or maybe we\'re just offline?)')
+    ui_bullets(c(
+      "x" = 'Unable to confirm the GitHub remote configuration is
+             "pull request ready".',
+      "i" = "You probably need to configure a personal access token for
+             {.val {tr$host}}.",
+      "i" = "See {.run usethis::gh_token_help()} for help with that.",
+      "i" = "(Or maybe we're just offline?)"
+    ))
     if (ui_github_remote_config_wat(cfg)) {
-      ui_stop("Aborting")
+      ui_bullets(c("x" = "Cancelling."))
+      return(invisible())
     }
   }
 
+  default_branch <- git_default_branch()
   challenge_non_default_branch(
-    "Are you sure you want to create a PR branch based on a non-default branch?"
+    "Are you sure you want to create a PR branch based on a non-default branch?",
+    default_branch = default_branch
   )
 
   online <- is_online(tr$host)
@@ -187,7 +198,6 @@ pr_init <- function(branch) {
     #    consider that the pull may be affected by uncommitted changes or a
     #    merge
     current_branch <- git_branch()
-    default_branch <- git_branch_default()
     if (current_branch == default_branch) {
       # override for mis-configured forks, that have default branch tracking
       # the fork (origin) instead of the source (upstream)
@@ -198,58 +208,63 @@ pr_init <- function(branch) {
     if (!is.na(remref)) {
       comparison <- git_branch_compare(current_branch, remref)
       if (comparison$remote_only > 0) {
-        challenge_uncommitted_changes(untracked = TRUE)
+        challenge_uncommitted_changes()
       }
-      ui_done("Pulling changes from {ui_value(remref)}")
+      ui_bullets(c("v" = "Pulling changes from {.val {remref}}."))
       git_pull(remref = remref, verbose = FALSE)
     }
   } else {
-    ui_info("
-      Unable to pull changes for current branch, since we are offline")
+    ui_bullets(c(
+      "!" = "Unable to pull changes for current branch, since we are offline."
+    ))
   }
 
-  ui_done("Creating and switching to local branch {ui_value(branch)}")
+  ui_bullets(c("v" = "Creating and switching to local branch {.val {branch}}."))
   gert::git_branch_create(branch, repo = repo)
   config_key <- glue("branch.{branch}.created-by")
   gert::git_config_set(config_key, value = "usethis::pr_init", repo = repo)
 
-  ui_todo("Use {ui_code('pr_push()')} to create PR.")
+  ui_bullets(c("_" = "Use {.run usethis::pr_push()} to create a PR."))
   invisible()
 }
 
 #' @export
 #' @rdname pull-requests
 pr_resume <- function(branch = NULL) {
+  repo <- git_repo()
+
   if (is.null(branch)) {
-    ui_info("
-      No branch specified ... looking up local branches and associated PRs")
-    branch <- choose_branch()
+    ui_bullets(c(
+      "i" = "No branch specified ... looking up local branches and associated PRs."
+    ))
+    default_branch <- git_default_branch()
+    branch <- choose_branch(exclude = default_branch)
     if (is.null(branch)) {
-      ui_oops("Repo doesn't seem to have any non-default branches")
+      ui_bullets(c("x" = "Repo doesn't seem to have any non-default branches."))
       return(invisible())
     }
     if (length(branch) == 0) {
-      ui_oops("No branch selected, exiting")
+      ui_bullets(c("x" = "No branch selected, exiting."))
       return(invisible())
     }
   }
-  stopifnot(is_string(branch))
+  check_string(branch)
 
-  repo <- git_repo()
   if (!gert::git_branch_exists(branch, local = TRUE, repo = repo)) {
-    code <- glue("pr_init(\"{branch}\")")
-    ui_stop("
-      No branch named {ui_value(branch)} exists
-      Call {ui_code(code)} to create a new PR branch")
+    code <- glue('usethis::pr_init("{branch}")')
+    ui_abort(c(
+      "x" = "No branch named {.val {branch}} exists.",
+      "_" = "Call {.run {code}} to create a new PR branch."
+    ))
   }
 
-  challenge_uncommitted_changes(untracked = TRUE)
+  challenge_uncommitted_changes()
 
-  ui_done("Switching to branch {ui_value(branch)}")
+  ui_bullets(c("v" = "Switching to branch {.val {branch}}."))
   gert::git_branch_checkout(branch, repo = repo)
   git_pull()
 
-  ui_todo("Use {ui_code('pr_push()')} to create or update PR.")
+  ui_bullets(c("_" = "Use {.run usethis::pr_push()} to create or update PR."))
   invisible()
 }
 
@@ -266,18 +281,19 @@ pr_resume <- function(branch = NULL) {
 #' pr_fetch(123)
 #' }
 pr_fetch <- function(number = NULL, target = c("source", "primary")) {
+  repo <- git_repo()
   tr <- target_repo(github_get = NA, role = target, ask = FALSE)
   challenge_uncommitted_changes()
 
   if (is.null(number)) {
-    ui_info("No PR specified ... looking up open PRs")
+    ui_bullets(c("i" = "No PR specified ... looking up open PRs."))
     pr <- choose_pr(tr = tr)
     if (is.null(pr)) {
-      ui_oops("No open PRs found for {ui_value(tr$repo_spec)}")
+      ui_bullets(c("x" = "No open PRs found for {.val {tr$repo_spec}}."))
       return(invisible())
     }
     if (min(lengths(pr)) == 0) {
-      ui_oops("No PR selected, exiting")
+      ui_bullets(c("x" = "No PR selected, exiting."))
       return(invisible())
     }
   } else {
@@ -285,26 +301,28 @@ pr_fetch <- function(number = NULL, target = c("source", "primary")) {
   }
 
   if (is.na(pr$pr_repo_owner)) {
-    ui_stop("The repo where PR {number} originates seems to have been deleted")
+    ui_abort("
+      The repo or branch where {.href [PR #{pr$pr_number}]({pr$pr_html_url})} originates seems to have been
+      deleted.")
   }
 
   pr_user <- glue("@{pr$pr_user}")
-  ui_done("
-    Checking out PR {ui_value(pr$pr_string)} ({ui_field(pr_user)}): \\
-    {ui_value(pr$pr_title)}")
+  ui_bullets(c(
+    "v" = "Checking out PR {.val {pr$pr_string}} ({.field {pr_user}}):
+           {.val {pr$pr_title}}."
+  ))
 
   if (pr$pr_from_fork && isFALSE(pr$maintainer_can_modify)) {
-    ui_info("
-      Note that user does NOT allow maintainer to modify this PR at this \\
-      time, although this can be changed.")
+    ui_bullets(c(
+      "!" = "Note that user does NOT allow maintainer to modify this PR at this
+             time, although this can be changed."
+    ))
   }
 
-  repo <- git_repo()
-
   remote <- github_remote_list(pr$pr_remote)
   if (nrow(remote) == 0) {
     url <- switch(tr$protocol, https = pr$pr_https_url, ssh = pr$pr_ssh_url)
-    ui_done("Adding remote {ui_value(pr$pr_remote)} as {ui_value(url)}")
+    ui_bullets(c("v" = "Adding remote {.val {pr$pr_remote}} as {.val {url}}."))
     gert::git_remote_add(url = url, name = pr$pr_remote, repo = repo)
     config_key <- glue("remote.{pr$pr_remote}.created-by")
     gert::git_config_set(config_key, "usethis::pr_fetch", repo = repo)
@@ -324,9 +342,10 @@ pr_fetch <- function(number = NULL, target = c("source", "primary")) {
 
   # Create local branch, if necessary, and switch to it ----
   if (!gert::git_branch_exists(pr$pr_local_branch, local = TRUE, repo = repo)) {
-    ui_done("
-      Creating and switching to local branch {ui_value(pr$pr_local_branch)}")
-    ui_done("Setting {ui_value(pr_remref)} as remote tracking branch")
+    ui_bullets(c(
+      "v" = "Creating and switching to local branch {.val {pr$pr_local_branch}}.",
+      "v" = "Setting {.val {pr_remref}} as remote tracking branch."
+    ))
     gert::git_branch_create(pr$pr_local_branch, ref = pr_remref, repo = repo)
     config_key <- glue("branch.{pr$pr_local_branch}.created-by")
     gert::git_config_set(config_key, "usethis::pr_fetch", repo = repo)
@@ -336,7 +355,7 @@ pr_fetch <- function(number = NULL, target = c("source", "primary")) {
   }
 
   # Local branch pre-existed; make sure tracking branch is set, switch, & pull
-  ui_done("Switching to branch {ui_value(pr$pr_local_branch)}")
+  ui_bullets(c("v" = "Switching to branch {.val {pr$pr_local_branch}}."))
   gert::git_branch_checkout(pr$pr_local_branch, repo = repo)
   config_url <- glue("branch.{pr$pr_local_branch}.pr-url")
   gert::git_config_set(config_url, pr$pr_html_url, repo = repo)
@@ -344,7 +363,7 @@ pr_fetch <- function(number = NULL, target = c("source", "primary")) {
   pr_branch_ours_tracking <- git_branch_tracking(pr$pr_local_branch)
   if (is.na(pr_branch_ours_tracking) ||
       pr_branch_ours_tracking != pr_remref) {
-    ui_done("Setting {ui_value(pr_remref)} as remote tracking branch")
+    ui_bullets(c("v" = "Setting {.val {pr_remref}} as remote tracking branch."))
     gert::git_branch_set_upstream(pr_remref, repo = repo)
   }
   git_pull(verbose = FALSE)
@@ -353,41 +372,36 @@ pr_fetch <- function(number = NULL, target = c("source", "primary")) {
 #' @export
 #' @rdname pull-requests
 pr_push <- function() {
+  repo <- git_repo()
   cfg <- github_remote_config(github_get = TRUE)
-  check_ours_or_fork(cfg)
-  check_pr_branch()
+  check_for_config(cfg, ok_configs = c("ours", "fork"))
+  default_branch <- git_default_branch()
+  check_pr_branch(default_branch)
   challenge_uncommitted_changes()
 
-  repo <- git_repo()
   branch <- git_branch()
   remref <- git_branch_tracking(branch)
   if (is.na(remref)) {
     # this is the first push
     if (cfg$type == "fork" && cfg$upstream$can_push && is_interactive()) {
       choices <- c(
-        origin   = glue(
-          "{cfg$origin$repo_spec} = {ui_value('origin')} (external PR)"),
-        upstream = glue(
-          "{cfg$upstream$repo_spec} = {ui_value('upstream')} (internal PR)")
+        origin   = ui_pre_glue("
+          <<cfg$origin$repo_spec>> = {.val origin} (external PR)"),
+        upstream = ui_pre_glue("
+          <<cfg$upstream$repo_spec>> = {.val upstream} (internal PR)")
       )
+      choices_formatted <- map_chr(choices, cli::format_inline)
       title <- glue("Which repo do you want to push to?")
-      choice <- utils::menu(choices, graphics = FALSE, title = title)
-      remote <-  names(choices)[[choice]]
+      choice <- utils::menu(choices_formatted, graphics = FALSE, title = title)
+      remote <- names(choices)[[choice]]
     } else {
       remote <- "origin"
     }
-    ui_done("
-      Pushing local {ui_value(branch)} branch to {ui_value(remote)} remote")
-    gert::git_push(remote = remote, verbose = FALSE, repo = repo)
+
+    git_push_first(branch, remote)
   } else {
     check_branch_pulled(use = "pr_pull()")
-    ui_done("Pushing local {ui_value(branch)} branch to {ui_value(remref)}")
-    gert::git_push(
-      remote = remref_remote(remref),
-      refspec = glue("refs/heads/{branch}:refs/heads/{remref_branch(remref)}"),
-      verbose = FALSE,
-      repo = repo
-    )
+    git_push(branch, remref)
   }
 
   # Prompt to create PR if does not exist yet
@@ -396,8 +410,9 @@ pr_push <- function() {
   if (is.null(pr)) {
     pr_create()
   } else {
-    ui_todo("
-      View PR at {ui_value(pr$pr_html_url)} or call {ui_code('pr_view()')}")
+    ui_bullets(c(
+      "_" = "View PR at {.url {pr$pr_html_url}} or call {.run usethis::pr_view()}."
+    ))
   }
 
   invisible()
@@ -406,12 +421,18 @@ pr_push <- function() {
 #' @export
 #' @rdname pull-requests
 pr_pull <- function() {
-  check_ours_or_fork()
-  check_pr_branch()
+  cfg <- github_remote_config(github_get = TRUE)
+  check_for_config(cfg)
+  default_branch <- git_default_branch()
+  check_pr_branch(default_branch)
   challenge_uncommitted_changes()
 
   git_pull()
 
+  # note associated PR in git config, if applicable
+  tr <- target_repo(cfg, ask = FALSE)
+  pr_find(tr = tr)
+
   invisible(TRUE)
 }
 
@@ -420,9 +441,8 @@ pr_pull <- function() {
 pr_merge_main <- function() {
   tr <- target_repo(github_get = TRUE, ask = FALSE)
   challenge_uncommitted_changes()
-  remref <- glue("{tr$remote}/{git_branch_default()}")
-  ui_done("
-    Pulling changes from {ui_value(remref)} (default branch of source repo)")
+  remref <- glue("{tr$remote}/{tr$default_branch}")
+  ui_bullets(c("v" = "Pulling changes from {.val {remref}}."))
   git_pull(remref, verbose = FALSE)
 }
 
@@ -433,17 +453,19 @@ pr_view <- function(number = NULL, target = c("source", "primary")) {
   url <- NULL
   if (is.null(number)) {
     branch <- git_branch()
-    default_branch <- git_branch_default()
+    default_branch <- git_default_branch()
     if (branch != default_branch) {
-      url <- pr_url(tr = tr)
+      url <- pr_url(branch = branch, tr = tr)
       if (is.null(url)) {
-        ui_info("
-          Current branch ({ui_value(branch)}) does not appear to be \\
-          connected to a PR")
+        ui_bullets(c(
+          "i" = "Current branch ({.val {branch}}) does not appear to be
+                 connected to a PR."
+        ))
       } else {
         number <- sub("^.+pull/", "", url)
-        ui_info("
-          Current branch ({ui_value(branch)}) is connected to PR #{number}")
+        ui_bullets(c(
+          "i" = "Current branch ({.val {branch}}) is connected to PR #{number}."
+        ))
       }
     }
   } else {
@@ -451,14 +473,14 @@ pr_view <- function(number = NULL, target = c("source", "primary")) {
     url <- pr$pr_html_url
   }
   if (is.null(url)) {
-    ui_info("No PR specified ... looking up open PRs")
+    ui_bullets(c("i" = "No PR specified ... looking up open PRs."))
     pr <- choose_pr(tr = tr)
     if (is.null(pr)) {
-      ui_oops("No open PRs found for {ui_value(tr$repo_spec)}")
+      ui_bullets(c("x" = "No open PRs found for {.val {tr$repo_spec}}."))
       return(invisible())
     }
     if (min(lengths(pr)) == 0) {
-      ui_oops("No PR selected, exiting")
+      ui_bullets(c("x" = "No PR selected, exiting."))
       return(invisible())
     }
     url <- pr$pr_html_url
@@ -472,20 +494,24 @@ pr_pause <- function() {
   # intentionally naive selection of target repo
   tr <- target_repo(github_get = FALSE, ask = FALSE)
 
-  default_branch <- git_branch_default()
+  ui_bullets(c("v" = "Switching back to the default branch."))
+  default_branch <- git_default_branch()
   if (git_branch() == default_branch) {
-    ui_info("
-      Already on this repo's default branch ({ui_value(default_branch)})
-      Nothing to do")
+    ui_bullets(c(
+      "!" = "Already on this repo's default branch ({.val {default_branch}}),
+             nothing to do."
+    ))
     return(invisible())
   }
   challenge_uncommitted_changes()
   # TODO: what happens here if offline?
   check_branch_pulled(use = "pr_pull()")
 
-  ui_done("Switching back to default branch ({ui_value(default_branch)})")
+  ui_bullets(c(
+    "v" = "Switching back to default branch ({.val {default_branch}})."
+  ))
   gert::git_branch_checkout(default_branch, repo = git_repo())
-  pr_pull_source_override(tr = tr)
+  pr_pull_source_override(tr = tr, default_branch = default_branch)
 }
 
 #' @export
@@ -506,13 +532,21 @@ pr_forget <- function() pr_clean(mode = "forget")
 pr_clean <- function(number = NULL,
                      target = c("source", "primary"),
                      mode = c("finish", "forget")) {
+  withr::defer(rstudio_git_tickle())
   mode <- match.arg(mode)
   repo <- git_repo()
   tr <- target_repo(github_get = NA, role = target, ask = FALSE)
+  default_branch <- git_default_branch()
 
   if (is.null(number)) {
-    check_pr_branch()
+    check_pr_branch(default_branch)
     pr <- pr_find(git_branch(), tr = tr, state = "all")
+    # if the remote branch has already been deleted (probably post-merge), we
+    # can't always reverse engineer what the corresponding local branch was, but
+    # we already know it -- it's how we found the PR in the first place!
+    if (!is.null(pr)) {
+      pr$pr_local_branch <- pr$pr_local_branch %|% git_branch()
+    }
   } else {
     pr <- pr_get(number = number, tr = tr)
   }
@@ -525,39 +559,46 @@ pr_clean <- function(number = NULL,
     }
     tracking_branch <- git_branch_tracking(pr_local_branch)
     if (is.na(tracking_branch)) {
-      if (ui_nope("
-        Local branch {ui_value(pr_local_branch)} has no associated remote \\
-        branch.
-        If we delete {ui_value(pr_local_branch)}, any work that exists only \\
-        on this branch work may be hard for you to recover.
-        Proceed anyway?")) {
-        ui_stop("Aborting.")
+      if (ui_nah(c(
+        "!" = "Local branch {.val {pr_local_branch}} has no associated remote
+               branch.",
+        "i" = "If we delete {.val {pr_local_branch}}, any work that exists only
+               on this branch may be hard for you to recover.",
+        " " = "Proceed anyway?"
+      ))) {
+        ui_bullets(c("x" = "Cancelling."))
+        return(invisible())
       }
     } else {
       cmp <- git_branch_compare(
         branch = pr_local_branch,
         remref = tracking_branch
       )
-      if (cmp$local_only > 0 && ui_nope("
-          Local branch {ui_value(pr_local_branch)} has 1 or more commits \\
-          that have not been pushed to {ui_value(tracking_branch)}.
-          If we delete {ui_value(pr_local_branch)}, this work may be hard \\
-          for you to recover.
-          Proceed anyway?")) {
-        ui_stop("Aborting.")
+      if (cmp$local_only > 0 && ui_nah(c(
+        "!" = "Local branch {.val {pr_local_branch}} has 1 or more commits that
+               have not been pushed to {.val {tracking_branch}}.",
+        "i" = "If we delete {.val {pr_local_branch}}, this work may be hard for
+               you to recover.",
+        " " = "Proceed anyway?"
+      ))) {
+        ui_bullets(c("x" = "Cancelling."))
+        return(invisible())
       }
     }
   }
 
-  default_branch <- git_branch_default()
   if (git_branch() != default_branch) {
-    ui_done("Switching back to default branch ({ui_value(default_branch)})")
+    ui_bullets(c(
+      "v" = "Switching back to default branch ({.val {default_branch}})."
+    ))
     gert::git_branch_checkout(default_branch, force = TRUE, repo = repo)
-    pr_pull_source_override(tr = tr)
+    pr_pull_source_override(tr = tr, default_branch = default_branch)
   }
 
   if (!is.na(pr_local_branch)) {
-    ui_done("Deleting local {ui_value(pr_local_branch)} branch")
+    ui_bullets(c(
+      "v" = "Deleting local {.val {pr_local_branch}} branch."
+    ))
     gert::git_branch_delete(pr_local_branch, repo = repo)
   }
 
@@ -565,18 +606,20 @@ pr_clean <- function(number = NULL,
     return(invisible())
   }
 
-  pr_branch_delete(pr)
+  if (mode == "finish") {
+    pr_branch_delete(pr)
+  }
 
-  # delete remote, if we added it AND no remaining tracking branches
+  # delete remote, if we (usethis) added it AND no remaining tracking branches
   created_by <- git_cfg_get(glue("remote.{pr$pr_remote}.created-by"))
-  if (is.null(created_by) || !grepl("^usethis::pr_", created_by)) {
+  if (is.null(created_by) || !grepl("^usethis::", created_by)) {
     return(invisible())
   }
 
   branches <- gert::git_branch_list(local = TRUE, repo = repo)
   branches <- branches[!is.na(branches$upstream), ]
   if (sum(grepl(glue("^refs/remotes/{pr$pr_remote}"), branches$upstream)) == 0) {
-   ui_done("Removing remote {ui_value(pr$pr_remote)}")
+    ui_bullets(c("v" = "Removing remote {.val {pr$pr_remote}}."))
     gert::git_remote_remove(remote = pr$pr_remote, repo = repo)
   }
   invisible()
@@ -586,26 +629,32 @@ pr_clean <- function(number = NULL,
 # we're in DEFAULT branch of a fork. I wish everyone set up DEFAULT to track the
 # DEFAULT branch in the source repo, but this protects us against sub-optimal
 # setup.
-pr_pull_source_override <- function(tr = NULL) {
+pr_pull_source_override <- function(tr = NULL, default_branch = NULL) {
   # naive selection of target repo; calling function should analyse the config
   tr <- tr %||% target_repo(github_get = FALSE, ask = FALSE)
+
+  # TODO: why does this not use a check_*() function, i.e. shared helper?
+  # I guess to issue a specific error message?
   current_branch <- git_branch()
-  default_branch <- git_branch_default()
+  default_branch <- default_branch %||% git_default_branch()
   if (current_branch != default_branch) {
-    ui_stop("
-      Internal error: pr_pull_source_override() should only be used when on \\
-      default branch")
+    ui_abort("
+      Internal error: {.fun pr_pull_source_override} should only be used when on
+      default branch.")
   }
-  # override for mis-configured forks, that have default branch tracking
+
+  # guard against mis-configured forks, that have default branch tracking
   # the fork (origin) instead of the source (upstream)
+  # TODO: should I just change the upstream tracking branch, i.e. fix it?
   remref <- glue("{tr$remote}/{default_branch}")
   if (is_online(tr$host)) {
-    ui_done("Pulling changes from {ui_value(remref)}")
+    ui_bullets(c("v" = "Pulling changes from {.val {remref}}."))
     git_pull(remref = remref, verbose = FALSE)
   } else {
-    ui_info("
-      Can't reach {ui_value(tr$host)}, therefore unable to pull changes from \\
-      {ui_value(remref)}")
+    ui_bullets(c(
+      "!" = "Can't reach {.val {tr$host}}, therefore unable to pull changes from
+             {.val {remref}}."
+    ))
   }
 }
 
@@ -614,12 +663,13 @@ pr_create <- function() {
   tracking_branch <- git_branch_tracking(branch)
   remote <- remref_remote(tracking_branch)
   remote_dat <- github_remotes(remote, github_get = FALSE)
-  ui_todo("Create PR at link given below")
+  ui_bullets(c("_" = "Create PR at link given below."))
   view_url(glue_data(remote_dat, "{host_url}/{repo_spec}/compare/{branch}"))
 }
 
-# retrieves 1 PR, if we can establish a tracking relationship between
-# `branch` and a PR branch
+# retrieves 1 PR, if:
+# * we can establish a tracking relationship between `branch` and a PR branch
+# * we can get the user to choose 1
 pr_find <- function(branch = git_branch(),
                     tr = NULL,
                     state = c("open", "closed", "all")) {
@@ -638,19 +688,23 @@ pr_find <- function(branch = git_branch(),
   state <- match.arg(state)
   remote <- remref_remote(tracking_branch)
   remote_dat <- github_remotes(remote)
-  pr_dat <- pr_list(
-    tr = tr,
-    state = state,
-    head = glue("{remote_dat$repo_owner}:{remref_branch(tracking_branch)}")
-  )
+
+  pr_head <- glue("{remote_dat$repo_owner}:{remref_branch(tracking_branch)}")
+  pr_dat <- pr_list(tr = tr, state = state, head = pr_head)
   if (nrow(pr_dat) == 0) {
     return(NULL)
   }
   if (nrow(pr_dat) > 1) {
-    ui_stop("
-      Branch {ui_value(branch)} is associated with multiple PRs: \\
-      {ui_value(paste0('#', pr_dat$pr_number))}")
+    spec <- sub(":", "/", pr_head)
+    ui_bullets(c("!" = "Multiple PRs are associated with {.val {spec}}."))
+    pr_dat <- choose_pr(pr_dat = pr_dat)
+    if (min(lengths(pr_dat)) == 0) {
+      ui_abort("
+        One of these PRs must be specified explicitly or interactively: \\
+        {.or {paste0('#', pr_dat$pr_number)}}.")
+    }
   }
+
   gert::git_config_set(config_url, pr_dat$pr_html_url, repo = git_repo())
   as.list(pr_dat)
 }
@@ -671,6 +725,7 @@ pr_data_tidy <- function(pr) {
   out <- list(
     pr_number     = pluck_int(pr, "number"),
     pr_title      = pluck_chr(pr, "title"),
+    pr_state      = pluck_chr(pr, "state"),
     pr_user       = pluck_chr(pr, "user", "login"),
     pr_created_at = pluck_chr(pr, "created_at"),
     pr_updated_at = pluck_chr(pr, "updated_at"),
@@ -699,7 +754,7 @@ pr_data_tidy <- function(pr) {
   gbl <- gbl[!is.na(gbl$upstream), c("name", "upstream")]
   gbl$upstream <- sub("^refs/remotes/", "", gbl$upstream)
   m <- match(pr_remref, gbl$upstream)
-  out$pr_local_branch <- if (is.na(m)) NA else gbl$name[m]
+  out$pr_local_branch <- if (is.na(m)) NA_character_ else gbl$name[m]
 
   # If the fork has been deleted, these are all NA
   # - Because pr$head$repo is NULL:
@@ -707,7 +762,7 @@ pr_data_tidy <- function(pr) {
   # - Because derived from those above:
   #   pr_remote, pr_remref pr_local_branch
   # I suppose one could already have a local branch, if you fetched the PR
-  # beforethe fork got deleted.
+  # before the fork got deleted.
   # But an initial pr_fetch() won't work if the fork has been deleted.
   # I'm willing to accept that the pr_*() functions don't necessarily address
   # the "deleted fork" scenario. It's relatively rare.
@@ -728,11 +783,11 @@ pr_list <- function(tr = NULL,
     "GET /repos/{owner}/{repo}/pulls",
     state = state, head = head, .limit = Inf
   )
-  if (!is.null(out$error)) {
-    ui_oops("Unable to retrieve PRs for {ui_value(tr$repo_spec)}")
-    prs <- NULL
-  } else {
+  if (is.null(out$error)) {
     prs <- out$result
+  } else {
+    ui_bullets(c("x" = "Unable to retrieve PRs for {.value {tr$repo_spec}}."))
+    prs <- NULL
   }
   no_prs <- length(prs) == 0
   if (no_prs) {
@@ -744,7 +799,8 @@ pr_list <- function(tr = NULL,
   if (no_prs) {
     out[0, ]
   } else {
-    out
+    pr_is_open <- out$pr_state == "open"
+    rbind(out[pr_is_open, ], out[!pr_is_open, ])
   }
 }
 
@@ -756,30 +812,18 @@ pr_get <- function(number, tr = NULL, github_get = NA) {
   pr_data_tidy(raw)
 }
 
-check_pr_branch <- function() {
-  default_branch <- git_branch_default()
-  if (git_branch() != default_branch) {
-    return(invisible())
-  }
-  ui_stop("
-    The {ui_code('pr_*()')} functions facilitate pull requests.
-    The current branch ({ui_value(default_branch)}) is this repo's default \\
-    branch, but pull requests should NOT come from the default branch.
-    Do you need to call {ui_code('pr_init()')} (new PR)?
-    Or {ui_code('pr_resume()')} or {ui_code('pr_fetch()')} (existing PR)?")
-}
-
 branches_with_no_upstream_or_github_upstream <- function(tr = NULL) {
   repo <- git_repo()
   gb_dat <- gert::git_branch_list(local = TRUE, repo = repo)
-  gb_dat <- gb_dat[
-    gb_dat$name != git_branch_default(),
-    c("name", "upstream", "updated")
-  ]
-  gb_dat$remref   <- sub("^refs/remotes/", "", gb_dat$upstream)
-  gb_dat$upstream <- NULL
-  gb_dat$remote   <- remref_remote(gb_dat$remref)
-  gb_dat$ref      <- remref_branch(gb_dat$remref)
+  gb_dat <- gb_dat[, c("name", "upstream", "updated")]
+  gb_dat$remref     <- sub("^refs/remotes/", "", gb_dat$upstream)
+  gb_dat$upstream   <- NULL
+  gb_dat$remote     <- remref_remote(gb_dat$remref)
+  gb_dat$ref        <- remref_branch(gb_dat$remref)
+  gb_dat$cfg_pr_url <- map_chr(
+    glue("branch.{gb_dat$name}.pr-url"),
+    ~ git_cfg_get(.x, where = "local") %||% NA_character_
+  )
 
   ghr <- github_remote_list(these = NULL)[["remote"]]
   gb_dat <- gb_dat[is.na(gb_dat$remref) | (gb_dat$remote %in% ghr), ]
@@ -792,75 +836,110 @@ branches_with_no_upstream_or_github_upstream <- function(tr = NULL) {
   )
   dat <- dat[order(dat$pr_number, dat$pr_updated_at, dat$updated, decreasing = TRUE), ]
 
+  missing_cfg <- is.na(dat$cfg_pr_url) & !is.na(dat$pr_html_url)
+  purrr::walk2(
+    glue("branch.{dat$name[missing_cfg]}.pr-url"),
+    dat$pr_html_url[missing_cfg],
+    ~ gert::git_config_set(.x, .y, repo = repo)
+  )
+
   dat
 }
 
-choose_branch <- function() {
+choose_branch <- function(exclude = character()) {
   if (!is_interactive()) {
     return(character())
   }
   dat <- branches_with_no_upstream_or_github_upstream()
+  dat <- dat[!dat$name %in% exclude, ]
   if (nrow(dat) == 0) {
     return()
   }
   prompt <- "Which branch do you want to checkout? (0 to exit)"
-  if (nrow(dat) > 9) {
-    branches_not_shown <- utils::tail(dat$name, -9)
-    n <- length(branches_not_shown)
-    dat <- dat[1:9, ]
-    pre <- glue("{n} branch{if (n > 1) 'es' else ''} not listed: ")
-    listing <- glue_collapse(
-      branches_not_shown, sep = ", ", width = getOption("width") - nchar(pre)
+  n_show_max <- 9
+  n <- nrow(dat)
+  n_shown <- compute_n_show(n, n_show_nominal = n_show_max)
+  n_not_shown <- n - n_shown
+  if (n_not_shown > 0) {
+    branches_not_shown <- utils::tail(dat$name, -n_shown)
+    dat <- dat[seq_len(n_shown), ]
+    fine_print <- cli::format_inline(
+      "{n_not_shown} branch{?/es} not listed: {.val {branches_not_shown}}"
     )
-    prompt <- glue("
-      {prompt}
-      {pre}{listing}")
+    prompt <- glue("{prompt}\n{fine_print}")
   }
-  dat$pretty_user <- map(dat$pr_user, ~ glue("@{.x}"))
   dat$pretty_name <- format(dat$name, justify = "right")
-  dat_pretty <- purrr::pmap(
-    dat[c("pretty_name", "pr_number", "pretty_user", "pr_title")],
-    function(pretty_name, pr_number, pretty_user, pr_title) {
+  dat_pretty <- purrr::pmap_chr(
+    dat[c("pretty_name", "pr_number", "pr_html_url", "pr_user", "pr_title")],
+    function(pretty_name, pr_number, pr_html_url, pr_user, pr_title) {
       if (is.na(pr_number)) {
-        glue("{pretty_name}")
+        pretty_name
       } else {
-        glue("{pretty_name} --> #{pr_number} ({ui_value(pretty_user)}): {pr_title}")
+        href_number <- ui_pre_glue("{.href [PR #<<pr_number>>](<<pr_html_url>>)}")
+        at_user <- glue("@{pr_user}")
+        template <- ui_pre_glue(
+          "{pretty_name} {cli::symbol$arrow_right} <<href_number>> ({.field <<at_user>>}): {.val <<pr_title>>}"
+        )
+        cli::format_inline(template)
       }
     }
   )
-  choice <- utils::menu(title = prompt, choices = dat_pretty)
+  choice <- utils::menu(title = prompt, choices = cli::ansi_strtrim(dat_pretty))
   dat$name[choice]
 }
 
-choose_pr <- function(tr = NULL) {
+choose_pr <- function(tr = NULL, pr_dat = NULL) {
   if (!is_interactive()) {
     return(list(pr_number = list()))
   }
-  tr <- tr %||% target_repo()
-  dat <- pr_list(tr)
-  if (nrow(dat) == 0) {
+  if (is.null(pr_dat)) {
+    tr <- tr %||% target_repo()
+    pr_dat <- pr_list(tr)
+  }
+  if (nrow(pr_dat) == 0) {
     return()
   }
-  # wording needs to make sense for pr_fetch() and pr_view()
+
+  # wording needs to make sense for several PR-choosing tasks, e.g. fetch, view,
+  # finish, forget
   prompt <- "Which PR are you interested in? (0 to exit)"
-  if (nrow(dat) > 9) {
-    n <- nrow(dat) - 9
-    dat <- dat[1:9, ]
-    prompt <- glue("
-      {prompt}
-      {n} more {if (n > 1) 'PRs are' else 'PR is'} open; \\
-      call {ui_code('browse_github_pulls()')} to browse all PRs")
+  n_show_max <- 9
+  n <- nrow(pr_dat)
+  n_shown <- compute_n_show(n, n_show_nominal = n_show_max)
+  n_not_shown <- n - n_shown
+  if (n_not_shown > 0) {
+    pr_dat <- pr_dat[seq_len(n_shown), ]
+    info1 <- cli::format_inline("Not shown: {n_not_shown} more PR{?s}.")
+    info2 <- cli::format_inline(
+      "Call {.run usethis::browse_github_pulls()} to browse all PRs."
+    )
+    prompt <- glue("{prompt}\n{info1}\n{info2}")
   }
-  pr_pretty <- purrr::pmap(
-    dat[c("pr_string", "pr_user", "pr_title")],
-    function(pr_string, pr_user, pr_title) {
+
+  some_closed <- any(pr_dat$pr_state == "closed")
+  pr_pretty <- purrr::pmap_chr(
+    pr_dat[c("pr_number", "pr_html_url", "pr_user", "pr_state", "pr_title")],
+    function(pr_number, pr_html_url, pr_user, pr_state, pr_title) {
+      href_number <- ui_pre_glue("{.href [PR #<<pr_number>>](<<pr_html_url>>)}")
       at_user <- glue("@{pr_user}")
-      glue("
-        {ui_value(pr_string)} ({ui_field(at_user)}): {ui_value(pr_title)}")
+      if (some_closed) {
+        template <- ui_pre_glue(
+          "<<href_number>> ({.field <<at_user>>}, {pr_state}): {.val <<pr_title>>}"
+        )
+        cli::format_inline(template)
+      } else {
+        template <- ui_pre_glue(
+          "<<href_number>> ({.field <<at_user>>}): {.val <<pr_title>>}"
+        )
+        cli::format_inline(template)
+      }
     }
   )
-  choice <- utils::menu(title = prompt, choices = pr_pretty)
-  as.list(dat[choice, ])
+  choice <- utils::menu(
+    title = prompt,
+    choices = cli::ansi_strtrim(pr_pretty)
+  )
+  as.list(pr_dat[choice, ])
 }
 
 # deletes the remote branch associated with a PR
@@ -888,22 +967,25 @@ pr_branch_delete <- function(pr) {
   pr_remref <- glue_data(pr, "{pr_remote}/{pr_ref}")
 
   if (is.null(pr_ref)) {
-    ui_info("
-      PR {ui_value(pr$pr_string)} originated from branch \\
-      {ui_value(pr_remref)}, which no longer exists")
+    ui_bullets(c(
+      "i" = "PR {.href [{pr$pr_string}]({pr$pr_html_url})} originated from branch {.val {pr_remref}},
+             which no longer exists."
+    ))
     return(invisible(FALSE))
   }
 
   if (is.na(pr$pr_merged_at)) {
-    ui_info("
-      PR {ui_value(pr$pr_string)} is unmerged, \\
-      we will not delete the remote branch {ui_value(pr_remref)}")
+    ui_bullets(c(
+      "i" = "PR {.href [{pr$pr_string}]({pr$pr_html_url})} is unmerged, we will not delete the
+             remote branch {.val {pr_remref}}."
+    ))
     return(invisible(FALSE))
   }
 
-  ui_done("
-    PR {ui_value(pr$pr_string)} has been merged, \\
-    deleting remote branch {ui_value(pr_remref)}")
+  ui_bullets(c(
+    "v" = "PR {.href [{pr$pr_string}]({pr$pr_html_url})} has been merged, deleting remote branch
+           {.val {pr_remref}}."
+  ))
   # TODO: tryCatch here?
   gh(
     "DELETE /repos/{owner}/{repo}/git/refs/{ref}",
@@ -911,3 +993,19 @@ pr_branch_delete <- function(pr) {
   )
   invisible(TRUE)
 }
+
+check_pr_branch <- function(default_branch = git_default_branch()) {
+  # the glue-ing happens inside check_current_branch(), where `gb` gives the
+  # current git branch
+  check_current_branch(
+    is_not = default_branch,
+    message = c(
+      "i" = "The {.code pr_*()} functions facilitate pull requests.",
+      "i" = "The current branch ({.val {gb}}) is this repo's default branch, but
+             pull requests should NOT come from the default branch.",
+      "i" = "Do you need to call {.fun usethis::pr_init} (new PR)?
+             Or {.fun usethis::pr_resume} or
+             {.fun usethis::pr_fetch} (existing PR)?"
+    )
+  )
+}
