@@ -21,16 +21,17 @@
 use_testthat <- function(edition = NULL, parallel = FALSE) {
   use_testthat_impl(edition, parallel = parallel)
 
-  ui_todo(
-    "Call {ui_code('use_test()')} to initialize a basic test file and open it \\
-    for editing."
-  )
+  ui_bullets(c(
+    "_" = "Call {.run usethis::use_test()} to initialize a basic test file and
+           open it for editing."
+  ))
 }
 
 use_testthat_impl <- function(edition = NULL, parallel = FALSE) {
   check_installed("testthat")
   if (utils::packageVersion("testthat") < "2.1.0") {
-    ui_stop("testthat 2.1.0 or greater needed. Please install before re-trying")
+    ui_abort("
+      {.pkg testthat} 2.1.0 or greater needed. Please install before re-trying")
   }
 
   if (is_package()) {
@@ -46,7 +47,7 @@ use_testthat_impl <- function(edition = NULL, parallel = FALSE) {
     }
   } else {
     if (!is.null(edition)) {
-      ui_stop("Can't declare testthat edition outside of a package")
+      ui_abort("Can't declare {.pkg testthat} edition outside of a package.")
     }
   }
 
@@ -70,11 +71,13 @@ check_edition <- function(edition = NULL) {
     version
   } else {
     if (!is.numeric(edition) || length(edition) != 1) {
-      ui_stop("`edition` must be a single number")
+      ui_abort("{.arg edition} must be a single number.")
     }
     if (edition > version) {
       vers <- utils::packageVersion("testthat")
-      ui_stop("`edition` ({edition}) not available in installed testthat ({vers})")
+      ui_abort("
+        {.var edition} ({edition}) not available in installed verion of
+        {.pkg testthat} ({vers}).")
     }
     as.integer(edition)
   }
