@@ -1,7 +1,7 @@
 # gert -------------------------------------------------------------------------
 
 gert_shush <- function(expr, regexp) {
-  stopifnot(is.character(regexp))
+  check_character(regexp)
   withCallingHandlers(
     gertMessage = function(cnd) {
       m <- map_lgl(regexp, ~ grepl(.x, cnd_message(cnd), perl = TRUE))
@@ -32,9 +32,9 @@ check_uses_git <- function() {
     return(invisible())
   }
 
-  ui_stop(c(
+  ui_abort(c(
     "Cannot detect that project is already a Git repository.",
-    "Do you need to run {ui_code('use_git()')}?"
+    "Do you need to run {.run usethis::use_git()}?"
   ))
 }
 
@@ -52,18 +52,44 @@ git_init <- function() {
 # config
 git_cfg_get <- function(name, where = c("de_facto", "local", "global")) {
   where <- match.arg(where)
+
+  if (where == "de_facto") {
+    return(git_cfg_get(name, "local") %||% git_cfg_get(name, "global"))
+  }
+
   if (where == "global" || !uses_git()) {
     dat <- gert::git_config_global()
   } else {
     dat <- gert::git_config(repo = git_repo())
   }
+
   if (where == "local") {
     dat <- dat[dat$level == "local", ]
   }
+
   out <- dat$value[tolower(dat$name) == tolower(name)]
   if (length(out) > 0) out else NULL
 }
 
+# more-specific case for user-name and -email
+git_user_get <- function(where = c("de_facto", "local", "global")) {
+  where <- match.arg(where)
+
+  list(
+    name = git_cfg_get("user.name", where),
+    email = git_cfg_get("user.email", where)
+  )
+}
+
+# translate from "usethis" terminology to "git" terminology
+where_from_scope <- function(scope = c("user", "project")) {
+  scope = match.arg(scope)
+
+  where_scope <- c(user = "global", project = "de_facto")
+
+  where_scope[scope]
+}
+
 # ensures that core.excludesFile is configured
 # if configured, leave well enough alone
 # if not, check for existence of one of the Usual Suspects; if found, configure
@@ -85,15 +111,16 @@ ensure_core_excludesFile <- function() {
     # express path relative to user's home directory, except on Windows
     path <- path("~", path_rel(path, path_home()))
   }
-  ui_done("Configuring {ui_field('core.excludesFile')}: {ui_path(path)}")
+  ui_bullets(c(
+    "v" = "Configuring {.field core.excludesFile}: {.path {pth(path)}}"
+  ))
   gert::git_config_global_set("core.excludesFile", path)
   invisible()
 }
 
-
 # Status------------------------------------------------------------------------
 git_status <- function(untracked) {
-  stopifnot(is_true(untracked) || is_false(untracked))
+  check_bool(untracked)
   st <- gert::git_status(repo = git_repo())
   if (!untracked) {
     st <- st[st$status != "new", ]
@@ -102,7 +129,7 @@ git_status <- function(untracked) {
 }
 
 # Commit -----------------------------------------------------------------------
-git_ask_commit <- function(message, untracked, paths = NULL) {
+git_ask_commit <- function(message, untracked, push = FALSE, paths = NULL) {
   if (!is_interactive() || !uses_git()) {
     return(invisible())
   }
@@ -110,9 +137,9 @@ git_ask_commit <- function(message, untracked, paths = NULL) {
   # this is defined here to encourage all commits to route through this function
   git_commit <- function(paths, message) {
     repo <- git_repo()
-    ui_done("Adding files")
+    ui_bullets(c("v" = "Adding files."))
     gert::git_add(paths, repo = repo)
-    ui_done("Making a commit with message {ui_value(message)}")
+    ui_bullets(c("v" = "Making a commit with message {.val {message}}."))
     gert::git_commit(message, repo = repo)
   }
 
@@ -128,24 +155,25 @@ git_ask_commit <- function(message, untracked, paths = NULL) {
   }
 
   paths <- sort(paths)
-  ui_paths <- map_chr(paths, ui_path)
-  if (n > 10) {
-    ui_paths <- c(ui_paths[1:10], "...")
-  }
-
-  if (n == 1) {
-    file_hint <- "There is 1 uncommitted file:"
-  } else {
-    file_hint <- "There are {n} uncommitted files:"
-  }
-  ui_line(c(
-    file_hint,
-    paste0("* ", ui_paths)
+  ui_paths <- usethis_map_cli(paths, template = '{.path {pth("<<x>>")}}')
+  file_hint <- "{cli::qty(n)}There {?is/are} {n} uncommitted file{?s}:"
+  ui_bullets(c(
+    "i" = file_hint,
+    bulletize(ui_paths, n_show = 10)
   ))
 
-  if (ui_yeah("Is it ok to commit {if (n == 1) 'it' else 'them'}?")) {
+  # Only push if no remote & a single change
+  push <- push && git_can_push(max_local = 1)
+
+  if (ui_yep(c(
+    "!" = "Is it ok to commit {if (push) 'and push '} {cli::qty(n)} {?it/them}?"
+  ))) {
     git_commit(paths, message)
+    if (push) {
+      git_push()
+    }
   }
+
   invisible()
 }
 
@@ -167,10 +195,13 @@ challenge_uncommitted_changes <- function(untracked = FALSE, msg = NULL) {
     we push, pull, switch, or compare branches"
   msg <- glue(msg %||% default_msg)
   if (git_uncommitted(untracked = untracked)) {
-    if (ui_yeah("{msg}\nDo you want to proceed anyway?")) {
+    if (ui_yep(c(
+      "!" = msg,
+      " " = "Do you want to proceed anyway?"
+    ))) {
       return(invisible())
     } else {
-      ui_stop("Uncommitted changes. Please commit before continuing.")
+      ui_abort("Uncommitted changes. Please commit before continuing.")
     }
   }
 }
@@ -183,27 +214,37 @@ git_conflict_report <- function() {
     return(invisible())
   }
 
-  conflicted_paths <- map_chr(conflicted, ui_path)
-  ui_line(c(
-    "There are {n} conflicted files:",
-    paste0("* ", conflicted_paths)
+  conflicted_paths <- usethis_map_cli(
+    conflicted,
+    template = '{.path {pth("<<x>>")}}'
+  )
+  file_hint <- "{cli::qty(n)}There {?is/are} {n} conflicted file{?s}:"
+  ui_bullets(c(
+    "i" = file_hint,
+    bulletize(conflicted_paths, n_show = 10)
   ))
 
-  msg <- glue("
-    Are you ready to sort this out?
-    If so, we will open the conflicted files for you to edit.")
-  yes <- "Yes, I'm ready to resolve the merge conflicts."
+  yes <- "Yes, open the conflicted files for editing."
+  yes_soft <- "Yes, but do not open the conflicted files."
   no <- "No, I want to abort this merge."
-  if (ui_yeah(msg, yes = yes, no = no, shuffle = FALSE)) {
-    ui_silence(purrr::walk(conflicted, edit_file))
-    ui_stop("
-      Please fix each conflict, save, stage, and commit.
-      To back out of this merge, run {ui_code('gert::git_merge_abort()')} \\
-      (in R) or {ui_code('git merge --abort')} (in the shell).")
-  } else {
+  choice <- utils::menu(
+    title = "Do you want to proceed with this merge?",
+    choices = c(yes, yes_soft, no)
+  )
+
+  if (choice < 1 || choice > 2) {
     gert::git_merge_abort(repo = git_repo())
-    ui_stop("Abandoning the merge, since it will cause merge conflicts")
+    ui_abort("Abandoning the merge, since it will cause merge conflicts.")
   }
+
+  if (choice == 1) {
+    ui_silence(purrr::walk(conflicted, edit_file))
+  }
+  ui_abort(c(
+    "Please fix each conflict, save, stage, and commit.",
+    "To back out of this merge, run {.code gert::git_merge_abort()}
+     (in R) or {.code git merge --abort} (in the shell)."
+  ))
 }
 
 # Remotes ----------------------------------------------------------------------
@@ -221,18 +262,18 @@ remref_branch <- function(remref) git_parse_remref(remref)$branch
 # Pull from remref or upstream tracking. If neither given/exists, do nothing.
 # Therefore, this does less than `git pull`.
 git_pull <- function(remref = NULL, verbose = TRUE) {
+  check_string(remref, allow_na = TRUE, allow_null = TRUE)
   repo <- git_repo()
   branch <- git_branch()
   remref <- remref %||% git_branch_tracking(branch)
   if (is.na(remref)) {
     if (verbose) {
-      ui_done("No remote branch to pull from for {ui_value(branch)}.")
+      ui_bullets(c("v" = "No remote branch to pull from for {.val {branch}}."))
     }
     return(invisible())
   }
-  stopifnot(is_string(remref))
   if (verbose) {
-    ui_done("Pulling from {ui_value(remref)}.")
+    ui_bullets(c("v" = "Pulling from {.val {remref}}."))
   }
   gert::git_fetch(
     remote = remref_remote(remref),
@@ -263,10 +304,10 @@ git_branch <- function() {
   info <- gert::git_info(repo = git_repo())
   branch <- info$shorthand
   if (identical(branch, "HEAD")) {
-    ui_stop("Detached head; can't continue")
+    ui_abort("Detached head; can't continue.")
   }
   if (is.na(branch)) {
-    ui_stop("On an unborn branch -- do you need to make an initial commit?")
+    ui_abort("On an unborn branch -- do you need to make an initial commit?")
   }
   branch
 }
@@ -274,7 +315,7 @@ git_branch <- function() {
 git_branch_tracking <- function(branch = git_branch()) {
   repo <- git_repo()
   if (!gert::git_branch_exists(branch, local = TRUE, repo = repo)) {
-    ui_stop("There is no local branch named {ui_value(branch)}")
+    ui_abort("There is no local branch named {.val {branch}}.")
   }
   gbl <- gert::git_branch_list(local = TRUE, repo = repo)
   sub("^refs/remotes/", "", gbl$upstream[gbl$name == branch])
@@ -292,9 +333,51 @@ git_branch_compare <- function(branch = git_branch(), remref = NULL) {
   list(local_only = out$ahead, remote_only = out$behind)
 }
 
+git_can_push <- function(max_local = Inf, branch = git_branch(), remref = NULL) {
+  remref <- remref %||% git_branch_tracking(branch)
+  if (is.null(remref)) {
+    return(FALSE)
+  }
+  comp <- git_branch_compare(branch, remref)
+  comp$remote_only == 0 && comp$local_only <= max_local
+}
+
+git_push <- function(branch = git_branch(), remref = NULL, verbose = TRUE) {
+  remref <- remref %||% git_branch_tracking(branch)
+  if (verbose) {
+    ui_bullets(c(
+      "v" = "Pushing local {.val {branch}} branch to {.val {remref}}."
+    ))
+  }
+
+  gert::git_push(
+    remote = remref_remote(remref),
+    refspec = glue("refs/heads/{branch}:refs/heads/{remref_branch(remref)}"),
+    verbose = FALSE,
+    repo = git_repo()
+  )
+}
+
+git_push_first <- function(branch = git_branch(), remote = "origin", verbose = TRUE) {
+  if (verbose) {
+    remref <- glue("{remote}/{branch}")
+    ui_bullets(c(
+      "v" = "Pushing {.val {branch}} branch to GitHub and setting
+             {.val {remref}} as upstream branch."
+    ))
+  }
+  gert::git_push(
+    remote = remote,
+    set_upstream = TRUE,
+    verbose = FALSE,
+    repo = git_repo()
+  )
+}
+
 # Checks ------------------------------------------------------------------
 
-check_current_branch <- function(is = NULL, is_not = NULL,
+check_current_branch <- function(is = NULL,
+                                 is_not = NULL,
                                  message = NULL) {
   gb <- git_branch()
 
@@ -303,9 +386,10 @@ check_current_branch <- function(is = NULL, is_not = NULL,
     if (gb == is) {
       return(invisible())
     } else {
-      msg <- message %||%
-        "Must be on branch {ui_value(is)}, not {ui_value(gb)}."
-      ui_stop(msg)
+      if (is.null(message)) {
+        message <- c("x" = "Must be on branch {.val {is}}, not {.val {gb}}.")
+      }
+      ui_abort(message)
     }
   }
 
@@ -314,9 +398,10 @@ check_current_branch <- function(is = NULL, is_not = NULL,
     if (gb != is_not) {
       return(invisible())
     } else {
-      msg <- message %||%
-        "Can't be on branch {ui_value(gb)}."
-      ui_stop(msg)
+      if (is.null(message)) {
+        message <- c("x" = "Can't be on branch {.val {gb}}.")
+      }
+      ui_abort(message)
     }
   }
 
@@ -333,41 +418,46 @@ check_branch_up_to_date <- function(direction = c("pull", "push"),
   use <- use %||% switch(direction, pull = "git pull", push = "git push")
 
   if (is.na(remref)) {
-    ui_done("Local branch {ui_value(branch)} is not tracking a remote branch.")
+    ui_bullets(c(
+      "i" = "Local branch {.val {branch}} is not tracking a remote branch."
+    ))
     return(invisible())
   }
 
   if (direction == "pull") {
-    ui_done("
-      Checking that local branch {ui_value(branch)} has the changes \\
-      in {ui_value(remref)}")
+    ui_bullets(c(
+      "v" = "Checking that local branch {.val {branch}} has the changes
+             in {.val {remref}}."
+    ))
   } else {
-    ui_done("
-      Checking that remote branch {ui_value(remref)} has the changes \\
-      in {ui_value(branch)}")
+    ui_bullets(c(
+      "v" = "Checking that remote branch {.val {remref}} has the changes
+             in {.val {branch}}."
+    ))
   }
 
   comparison <- git_branch_compare(branch, remref)
 
-  # TODO: properly pluralize "commit(s)" when I switch to cli
   if (direction == "pull") {
     if (comparison$remote_only == 0) {
       return(invisible())
     } else {
-      ui_stop("
-        Local branch {ui_value(branch)} is behind {ui_value(remref)} by \\
-        {comparison$remote_only} commit(s).
-        Please use {ui_code(use)} to update.")
+      ui_abort(c(
+        "Local branch {.val {branch}} is behind {.val {remref}} by
+         {comparison$remote_only} commit{?s}.",
+        "Please use {.code {use}} to update."
+      ))
     }
   } else {
     if (comparison$local_only == 0) {
       return(invisible())
     } else {
       # TODO: consider offering to push for them?
-      ui_stop("
-        Local branch {ui_value(branch)} is ahead of {ui_value(remref)} by \\
-        {comparison$local_only} commit(s).
-        Please use {ui_code(use)} to update.")
+      ui_abort(c(
+        "Local branch {.val {branch}} is ahead of {.val {remref}} by
+         {comparison$remote_only} commit{?s}.",
+        "Please use {.code {use}} to update."
+      ))
     }
   }
 }
