@@ -17,7 +17,7 @@ test_that("use_tidy_dependencies() isn't overly informative", {
 
   create_local_package()
   use_package_doc()
-  withr::local_options(usethis.quiet = FALSE)
+  withr::local_options(usethis.quiet = FALSE, cli.width = Inf)
 
   expect_snapshot(
     use_tidy_dependencies(),
@@ -57,7 +57,6 @@ test_that("use_tidy_github() adds and Rbuildignores files", {
 })
 
 test_that("styling the package works", {
-  skip_if(getRversion() < 3.2)
   skip_if_no_git_user()
   skip_if_not_installed("styler")
 
@@ -72,7 +71,6 @@ test_that("styling the package works", {
 
 
 test_that("styling of non-packages works", {
-  skip_if(getRversion() < 3.2)
   skip_if_no_git_user()
   skip_if_not_installed("styler")
 
